﻿using System;
using System.IO;
using System.Linq;
using System.Web.Mvc;

namespace prj_MasterDetailReport
{
    public class HomeController : Controller
    {
        [HttpGet]
        [Route("")]
        [Route("index")]
        public ActionResult Index()
        {
            return Resource("index.html");
        }

        [HttpGet]
        [Route("{file}")]
        [Route("ViewerApp/{file}")]
        public ActionResult Resource(string file)
        {
            var stream = GetType().Assembly.GetManifestResourceStream("prj_MasterDetailReport.wwwroot." + file);
            if (stream == null)
                return new HttpNotFoundResult();

            if (Path.GetExtension(file) == ".html")
                return new ContentResult() { Content = new StreamReader(stream).ReadToEnd(), ContentType = "text/html" };

            if (Path.GetExtension(file) == ".ico")
                using (var memoryStream = new MemoryStream())
                {
                    stream.CopyTo(memoryStream);
                    return new FileContentResult(memoryStream.ToArray(), "image/x-icon") { FileDownloadName = file };
                }

            using (var streamReader = new StreamReader(stream))
                return new FileContentResult(System.Text.Encoding.UTF8.GetBytes(streamReader.ReadToEnd()),
                    GetType(file))
                { FileDownloadName = file };
        }

        private string GetType(string file)
        {
            if (file.EndsWith(".css"))
                return "text/css";

            if (file.EndsWith(".js"))
                return "text/javascript";

            return "text/html";
        }

        [HttpGet]
        [Route("reports")]
        public ActionResult Reports()
        {
            string[] validExtensions = {".mdb", ".rdl", ".rdlx", ".rdlx-master", ".rpx" };

            var reportsList = typeof(HomeController).Assembly.GetManifestResourceNames()
                .Where(x => x.StartsWith(Startup.EmbeddedReportsPrefix) && validExtensions.Any(ext => x.EndsWith(ext, StringComparison.InvariantCultureIgnoreCase)))
                .Select(x => x.Substring(Startup.EmbeddedReportsPrefix.Length + 1))
                .ToArray();

            return new JsonResult
            {
                Data = reportsList,
                JsonRequestBehavior = JsonRequestBehavior.AllowGet
            };
        }
    }
}